==> nextcloud-23.0.3.tgz: nextcloud/apps/password_policy/l10n/fa.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password is among the 1,000,000 most common ones. Please make it unique." : "گذرواژه در میان 1000000 رایج ترین آن است. لطفا آن را منحصر به فرد کنید.",
    "Password is present in compromised password list. Please choose a different password." : "گذرواژه در لیست گذرواژه به خطر افتاده است. لطفاً یک رمز عبور دیگر انتخاب کردن",
    "Password needs to contain at least one numeric character." : "گذرواژه باید حداقل دارای یک شخصیت عددی باشد.",
    "Password needs to contain at least one special character." : "گذرواژه باید حداقل دارای یک شخصیت خاص باشد.",
    "Password needs to contain at least one lower and one upper case character." : "گذرواژه باید حداقل یک شخصیت کوچک و یک مورد بزرگ داشته باشد.",
    "Password policy" : "خط مشی رمز عبور",
    "Allows admins to configure a password policy" : "به مدیران اجازه می دهد خط مشی رمز عبور را پیکربندی کنند",
    "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "اجازه مدیر برای تعریف خاصی از پیش شرایط برای رمز عبور، به عنوان مثال، حداقل طول را اجرا کنید",
    "Forbid common passwords" : "ممنوع کردن کلمه عبور مشترک",
    "Enforce upper and lower case characters" : "کاراکترهای بزرگ و پایین را اجرا کنید",
    "Enforce numeric characters" : "اجرای شخصیت های عددی",
    "Enforce special characters" : "شخصیت های خاص را اجرا کنید",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "گذرواژه را در برابر لیست گذرواژه های نقض شده از hasibeenpwned.com بررسی کنید",
    "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "این بررسی یک هشی از رمز عبور ایجاد می کند و 5 کاراکتر اول این هش را به API haveibeenpwned.com می فرستد تا لیستی از همه هش ها را که با آن شروع می شود بازیابی کنید. سپس در مثال نکست کلود بررسی می کند که آیا رمز عبور در مجموعه نتایج قرار دارد یا خیر.",
    "Password needs to be at least %s characters long" : "حداقل باید رمزعبور باشد%s شخصیت های طولانی"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-25.0.8.tgz: nextcloud/apps/password_policy/l10n/fa.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password is among the 1,000,000 most common ones. Please make it unique." : "گذرواژه در میان 1000000 رایج ترین آن است. لطفا آن را منحصر به فرد کنید.",
    "Password is present in compromised password list. Please choose a different password." : "گذرواژه در لیست گذرواژه به خطر افتاده است. لطفاً یک رمز عبور دیگر انتخاب کردن",
    "Password needs to contain at least one numeric character." : "گذرواژه باید حداقل دارای یک شخصیت عددی باشد.",
    "Password needs to contain at least one special character." : "گذرواژه باید حداقل دارای یک شخصیت خاص باشد.",
    "Password needs to contain at least one lower and one upper case character." : "گذرواژه باید حداقل یک شخصیت کوچک و یک مورد بزرگ داشته باشد.",
    "Password policy" : "خط مشی رمز عبور",
    "Allows admins to configure a password policy" : "به مدیران اجازه می دهد خط مشی رمز عبور را پیکربندی کنند",
    "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "اجازه مدیر برای تعریف خاصی از پیش شرایط برای رمز عبور، به عنوان مثال، حداقل طول را اجرا کنید",
    "Forbid common passwords" : "ممنوع کردن کلمه عبور مشترک",
    "Enforce upper and lower case characters" : "کاراکترهای بزرگ و پایین را اجرا کنید",
    "Enforce numeric characters" : "اجرای شخصیت های عددی",
    "Enforce special characters" : "شخصیت های خاص را اجرا کنید",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "گذرواژه را در برابر لیست گذرواژه های نقض شده از hasibeenpwned.com بررسی کنید",
    "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "این بررسی یک هشی از رمز عبور ایجاد می کند و 5 کاراکتر اول این هش را به API haveibeenpwned.com می فرستد تا لیستی از همه هش ها را که با آن شروع می شود بازیابی کنید. سپس در مثال نکست کلود بررسی می کند که آیا رمز عبور در مجموعه نتایج قرار دارد یا خیر.",
    "Unknown error" : "خطای ناشناخته",
    "Settings saved" : "تنظیمات ذخیره شد",
    "Saved" : "دخیره شد"
},
"nplurals=2; plural=(n > 1);");
